#

    	vocab

    		"key"
    			"vibe"

    		"public" and "private" key:
    			"verifier" and "signer"

    			private:
    				confidence
    				secret

    			public:
    				popularity, fame
    				society
    				landyard
    				open
    				share
    				address

    		"sign"
    			sign -> signature
    			authorize -> authorization
    			approve -> approval

    		"verify"
    			authenticate

    			legitimize
    			approve